*NAME*
    mirror - Mirror remote files or directories

*SYNOPSIS*
    mirror [options] [settings] [mirror-file] [site]

    All arguments may be specified in any order.

*DESCRIPTION*
    Download or update files and directories from a remote site to create
    a local mirror image.  Requires rsync to be installed locally and an rsync
    server to be running on the remote site.

    The *site* argument is any sub-string or pattern (regex) that matches one
    of the available sites listed in $sites from the mirror file[s].  If not
    specified, then the first entry in $sites is used.  The first entry in the
    list that matches *site* will be selected, so you must specify enough
    characters to uniquely match one one you want.

    If *mirror-file* is specified, it's settings append to or override the
    settings in _@ETC_PREFIX@/etc/mirror.conf_ and _~/.mirror_.  It can also
    be specified as a setting (e.g. mf=file) (see *SETTINGS* below).

    All command line arguments are optional.  All settings can be read from
    mirror files.  It also does not matter what order command line arguments
    are are specified in.  

*OPTIONS*
    *-z* and *-Z* override any --compress options set in $rsync_opts in the
    mirror files.

    *-h | --help*
        This help

    *-q | --quiet*
        Quiet mode.  Normally, *mirror* displays a header showing key settings
        when it runs, such as site, files, and destination.  This makes it
        completely quiet.  It has no effect, however, on the any verbose
        settings in $rsync_opts which controls how verbose rsync is.

    *-v | --verbose*
        Verbose mode.  This displays additional information such as the full
        rsync command line that is run to do the mirroring.  Like -q, it has
        no effect on rsync's verbosity.

    *-z*
        Turn on data compression during transfer

    *-Z*
        Turn off data compression

*SETTINGS*
    Settings are specified as  *variable=value*  or  *variable+=value*.

    Any setting in the mirror files may be overridden or appended to on
    the command line.  Spaces are allowed around the '=' or '+=' operators in
    the mirror files but *not* on the command line.

    The full variable names on the left side must be used in the mirror files
    (e.g. destination=/home/dcvs).  However, the command line is flexible.  The
    short versions are examples of how they can be specified on the command
    line to save typing.  Most intuitive short forms will work.
    Example:  
        mirror mf=./mirror-dcvs.conf
        is the same as
        mirror mirror_file=./mirror-dcvs.conf

    Here is the list of available settings:

    *mirror_file | config_file | mirror | conf | cf | mf*
    *destination | dest*
    *files*
    *rsync_opts  | rsync | rso | rs*
    *sites*

*CONFIGURATION*
    See the sample mirror files for examples.

    *Note:* 
        If a variable is set using a '*+=*' operator, then it appends to
        any existing setting, even from other mirror files.  This way you
        can set system wide defaults, such as for $rsync_opts, in
        _@ETC_PREFIX@/etc/mirror.conf_ and append to them in local mirror
        files and/or on the command line.

    Exclude/refuse file lists are not yet implemented.

*EXAMPLES*
    These examples are based on using the default _mirror-dcvs.conf_ file.
    The lines starting with a '*$*', which represents the prompt, are example
    commands.

    *$ mirror*
        Run mirror using the settings in _@ETC_PREFIX@/etc/mirror.conf_ and
        _~/.mirror_. 

    *$ mirror conf=@PREFIX@/share/examples/mirror/mirror-dcvs.conf*
    *$ mirror @PREFIX@/share/examples/mirror/mirror-dcvs.conf*
        Update the CVSROOT, src, and doc directories in your local dcvs
        repository from TheShell.com.  The *conf=* portion is generally
        optional.  If an argument exists as a file, then it is assumed to be
        a mirror file.

    *$ cp @PREFIX@/share/examples/mirror/mirror-dcvs.conf ~/.mirror*
        Use _mirror-dcvs.conf_ as the default mirror file so it does not have
        to be specified.  
        *Warning:*
            Beware that after doing this, if a different mirror file is 
            specified on the command line that has any variables that are only
            appended to, they will be combined with the values from this file.
    
    *Note:*
        For the rest of the examples, it is assumed the above *cp* command has
        been run.

    *$ mirror allbsd*
        Update from _rsync.AllBSD.org::dragonfly-cvs_.

    *$ mirror chl files+=site*
        Update from _chlamydia.fs.ei.tum.de::dragonfly-cvs_ and also get the
        The DragonFly website code even though it is commented out in the
        mirror file.
    
    *$ mirror dest=/home/dcvs-theshell rsync+=--progress files=doc*
        Update only the _doc_ directory from the default site,
        _rsync.TheShell.com::DragonFly/dcvs_, with rsync's progress meter on
        during file transfers, and store the updated/downloaded files in
        the directory, _/home/dcvs-theshell_.

*FILES*
    _@ETC_PREFIX@/etc/mirror.conf_
        This file is read first, if it exists, for system wide default
        settings.

    _~/.mirror_
        This file is read second, if it exists, for default user settings.
        It will append to or replace settings in /etc/mirror.conf.

    _@PREFIX@/share/examples/mirror/_
        This directory contains example mirror files such as
        _mirror-dcvs.conf_ for maintaining a copy of the DragonFly BSD source
        code repository.

        You can use it in a similar way as cvsup, e.g.
            *mirror config=@PREFIX@/share/examples/mirror/mirror-dcvs.conf*

        Or you can copy a config file to _~/.mirror_ (in your home directory)
        and and just run *mirror* with no arguments.

*SEE ALSO*
    rsync(1)

*AUTHOR*
    Vincent Stemen

